==> jscommunicator-1.0.20.tgz: package/src/basePush.js <==
"use strict"

let base =  require('./base');
let types = require('./types');
let exceptions = require('./exceptions');
let emptyValues = ['', null, {}, [], undefined];


class BasePush extends base.Base {
    constructor(host, config, appName){
        super(host, config, appName);
        this.push_relation_keys = ['app_version', 'last_active'];
        this.push_relations = ['=', '>', '<', '>=', '<='];
        this.comm_app_name = '';
        this.mandatory_keys = [
            'service', 'reference_id', 'reference_type', 'data'
        ];
        this.queueName = '';
        this.pushNotification = {};
    }

    isEmpty(value) {
        if (emptyValues.indexOf(value) > -1)
            return true;
        return false;
    }

    removeEmptyKeys(pushDict) {
        var updated_dict = {}
        for (var key in pushDict) {
            var value = pushDict[key];
            if (this.isEmpty(value))
                continue;
            else if (typeof(value) == "object") {
                var updated_value = this.removeEmptyKeys(value);
                if (this.isEmpty(updated_value))
                    continue;
                updated_dict[key] = updated_value;
            }
            else {
                updated_dict[key] = value;
            }
        }
        return updated_dict;
    }

    sendPushNotification() {
        let job_dict = this.pushNotification;
        job_dict = this.validate(job_dict);
        this.send(job_dict, this.queueName, 0);
    }

    addHeaders(input_object) {
        this.pushNotification.reference_id = input_object.reference_id;
        this.pushNotification.reference_type = input_object.reference_type;
        if ('is_silent' in input_object)
            this.pushNotification.is_silent = input_object.is_silent;
        if ('is_content_available' in input_object)
            this.pushNotification.is_content_available = input_object.is_content_available;
        if ('push_type' in input_object)
            this.pushNotification.push_type = input_object.push_type;
    }

    addFilters(input_object) {
        if ('last_active' in input_object)
            this.pushNotification.last_active = input_object.last_active;
        if ('account_id' in input_object)
            this.pushNotification.account_id = input_object.account_id;
        if ('device_id' in input_object)
            this.pushNotification.device_id = input_object.device_id;
        if ('app_version' in input_object)
            this.pushNotification.app_version = input_object.app_version;
    }

    addData(input_object) {
        if ('data' in input_object)
            Object.assign(this.pushNotification.data, input_object.data);
    }

    preparePushBody(input_object) {
        this.addHeaders(input_object);
        this.addFilters(input_object);
        this.addData(input_object);
    }

    validatePushType(push_type) {
        throw new exceptions.PushNotImplementedException(
            'Validate push type has not been implemented'
        )
    }

    validateFilters(pushDict) {
        throw new exceptions.PushNotImplementedException(
            'Validate filters has not been implemented'
        )
    }

    validatePushRelationKeys(pushDict) {
        for (var index = 0; index < this.push_relation_keys.length; index++) {
            let key = this.push_relation_keys[index];
            let value = pushDict[key] ? 'key' in pushDict : {};
            if (Object.keys(value).length !== 0) {
                if (['value', 'relation'] !== Object.keys(value)) {
                    throw new exceptions.PushValidationException(
                        "Invalid keys in last active"
                    );
                }
                if (this.push_relations.indexOf(value['relation']) < 0) {
                    throw new exceptions.PushValidationException(
                        "Invalid relation in last active"
                    );
                }
            }
        }
    }

    validateMandatoryKeys(mandatory_keys, pushDict) {
        let missing_keys = Array.from(new Set(mandatory_keys) - new Set(Object.keys(pushDict)));
        if (missing_keys.length !== 0)
            throw new exceptions.PushValidationException(
                "Missing Mandatory Keys {}".format(missing_keys)
            );
        for (var index = 0; index < mandatory_keys.length; index++) {
            let key = mandatory_keys[index];
            if (emptyValues.indexOf(pushDict[key]) >= 0)
                throw new exceptions.PushValidationException(
                    "Key {} cannot be empty".format(key)
                );
        }
    }

    validateTypes(pushDict) {
        let ptypes = new types.PushDataTypes();
        for (var key in ptypes.types) {
            let val = pushDict[key];
            if (val === undefined) {
                return;
            }
            if ((emptyValues.indexOf(val) >= 0) || (typeof(val) !== ptypes.types[key])) {
                throw new exceptions.PushValidationException(
                    "Invalid Type for key " + key
                );
            }
        }
    }

    validateAndroidData(android_data) {
        if (emptyValues.indexOf(android_data) >= 0)
            throw new exceptions.PushValidationException("No Data in Android Payload");
    }

    validateIosData(android_data, is_ios_silent, pushDict) {
        if (emptyValues.indexOf(android_data) >= 0)
            throw new exceptions.PushValidationException("No Data in Ios Payload");
        if (is_ios_silent) {
            pushDict.is_content_available = true;
            if (Object.keys(ios_data) !== ['custom']) {
                throw new exceptions.PushValidationException(
                    "Silent Push can only have custom keys"
                );
            }
        }
        else if (Object.keys(ios_data) === ['custom']) {
            throw new exceptions.PushValidationException("Non Silent Push data cant be empty");
        }
    }

    validateData(pushDict) {
        if (pushDict.is_silent === undefined)
            throw new exceptions.PushValidationException("Is Silent value cannot be undefined");
        if ('android' === pushDict.app_name)
            this.validateAndroidData(pushDict.data)
        else if ('ios' === pushDict.app_name)
            this.validateIosData(pushDict.data, pushDict.is_silent, pushDict)
    }

    validate(pushDict) {
        pushDict = this.removeEmptyKeys(pushDict);
        this.validateTypes(pushDict);
        this.validateMandatoryKeys(this.mandatory_keys, pushDict);
        this.validateFilters(pushDict);
        this.validateData(pushDict);
        this.validatePushType(pushDict.push_type);
        pushDict.app_name = this.comm_app_name;
        return pushDict;
    }
}

module.exports = {
    BasePush: BasePush
}

==> jscommunicator-1.0.21.tgz: package/src/basePush.js <==
"use strict"

let base =  require('./base');
let types = require('./types');
let exceptions = require('./exceptions');
let emptyValues = ['', null, {}, [], undefined];


class BasePush extends base.Base {
    constructor(host, config, appName){
        super(host, config, appName);
        this.push_relation_keys = ['app_version', 'last_active'];
        this.push_relations = ['=', '>', '<', '>=', '<='];
        this.comm_app_name = '';
        this.mandatory_keys = [
            'service', 'reference_id', 'reference_type', 'data'
        ];
        this.queueName = '';
        this.pushNotification = {};
    }

    isEmpty(value) {
        if (emptyValues.indexOf(value) > -1)
            return true;
        return false;
    }

    areArraysEqual(arr1, arr2) {
        return arr1.sort().toString() == arr2.sort().toString();
    }

    removeEmptyKeys(pushDict) {
        var updated_dict = {}
        for (var key in pushDict) {
            var value = pushDict[key];
            if (this.isEmpty(value))
                continue;
            else if (typeof(value) == "object") {
                var updated_value = this.removeEmptyKeys(value);
                if (this.isEmpty(updated_value))
                    continue;
                updated_dict[key] = updated_value;
            }
            else {
                updated_dict[key] = value;
            }
        }
        return updated_dict;
    }

    sendPushNotification() {
        let job_dict = this.pushNotification;
        job_dict = this.validate(job_dict);
        this.send(job_dict, this.queueName, 0);
    }

    addHeaders(input_object) {
        this.pushNotification.reference_id = input_object.reference_id;
        this.pushNotification.reference_type = input_object.reference_type;
        if ('is_silent' in input_object)
            this.pushNotification.is_silent = input_object.is_silent;
        if ('is_content_available' in input_object)
            this.pushNotification.is_content_available = input_object.is_content_available;
        if ('push_type' in input_object)
            this.pushNotification.push_type = input_object.push_type;
    }

    addFilters(input_object) {
        if ('last_active' in input_object)
            this.pushNotification.last_active = input_object.last_active;
        if ('account_id' in input_object)
            this.pushNotification.account_id = input_object.account_id;
        if ('device_id' in input_object)
            this.pushNotification.device_id = input_object.device_id;
        if ('app_version' in input_object)
            this.pushNotification.app_version = input_object.app_version;
    }

    addData(input_object) {
        if ('data' in input_object)
            Object.assign(this.pushNotification.data, input_object.data);
    }

    preparePushBody(input_object) {
        this.addHeaders(input_object);
        this.addFilters(input_object);
        this.addData(input_object);
    }

    validatePushType(push_type) {
        throw new exceptions.PushNotImplementedException(
            'Validate push type has not been implemented'
        )
    }

    validateFilters(pushDict) {
        throw new exceptions.PushNotImplementedException(
            'Validate filters has not been implemented'
        )
    }

    validatePushRelationKeys(pushDict) {
        for (var index = 0; index < this.push_relation_keys.length; index++) {
            let key = this.push_relation_keys[index];
            let value = pushDict[key] ? 'key' in pushDict : {};
            if (Object.keys(value).length !== 0) {
                if (['value', 'relation'] !== Object.keys(value)) {
                    throw new exceptions.PushValidationException(
                        "Invalid keys in last active"
                    );
                }
                if (this.push_relations.indexOf(value['relation']) < 0) {
                    throw new exceptions.PushValidationException(
                        "Invalid relation in last active"
                    );
                }
            }
        }
    }

    validateMandatoryKeys(mandatory_keys, pushDict) {
        let missing_keys = Array.from(new Set(mandatory_keys) - new Set(Object.keys(pushDict)));
        if (missing_keys.length !== 0)
            throw new exceptions.PushValidationException(
                "Missing Mandatory Keys {}".format(missing_keys)
            );
        for (var index = 0; index < mandatory_keys.length; index++) {
            let key = mandatory_keys[index];
            if (emptyValues.indexOf(pushDict[key]) >= 0)
                throw new exceptions.PushValidationException(
                    "Key {} cannot be empty".format(key)
                );
        }
    }

    validateTypes(pushDict) {
        let ptypes = new types.PushDataTypes();
        for (var key in ptypes.types) {
            let val = pushDict[key];
            if (val === undefined) {
                continue;
            }
            if ((emptyValues.indexOf(val) >= 0) || (typeof(val) !== ptypes.types[key])) {
                throw new exceptions.PushValidationException(
                    "Invalid Type for key " + key
                );
            }
        }
    }

    validateAndroidData(androidData) {
        if (emptyValues.indexOf(androidData) >= 0)
            throw new exceptions.PushValidationException("No Data in Android Payload");
    }

    validateIosData(iosData, isIosSilent, pushDict) {
        if (emptyValues.indexOf(iosData) >= 0)
            throw new exceptions.PushValidationException("No Data in Ios Payload");
        if (isIosSilent) {
            pushDict.is_content_available = true;
            if (!areArraysEqual(Object.keys(iosData), ['custom'])) {
                throw new exceptions.PushValidationException(
                    "Silent Push can only have custom keys"
                );
            }
        }
        else if (areArraysEqual(Object.keys(iosData), ['custom'])) {
            throw new exceptions.PushValidationException("Non Silent Push data cant be empty");
        }
    }

    validateData(pushDict) {
        if (pushDict.is_silent === undefined)
            throw new exceptions.PushValidationException("Is Silent value cannot be undefined");
        if ('android' === pushDict.app_name)
            this.validateAndroidData(pushDict.data)
        else if ('ios' === pushDict.app_name)
            this.validateIosData(pushDict.data, pushDict.is_silent, pushDict)
    }

    validate(pushDict) {
        pushDict = this.removeEmptyKeys(pushDict);
        this.validateTypes(pushDict);
        this.validateMandatoryKeys(this.mandatory_keys, pushDict);
        this.validateFilters(pushDict);
        this.validateData(pushDict);
        this.validatePushType(pushDict.push_type);
        pushDict.app_name = this.comm_app_name;
        return pushDict;
    }
}

module.exports = {
    BasePush: BasePush
}
